@@ -71,7 +71,7 @@ def libdoc(app: Application, robot_options_and_args: Tuple[str, ...]) -> None:
     )
     try:
         profile = (
-            load_robot_config_from_path(*config_files)
+            load_robot_config_from_path(*config_files, verbose_callback=app.verbose)
             .combine_profiles(*(app.config.profiles or []), verbose_callback=app.verbose, error_callback=app.error)
             .evaluated_with_env(verbose_callback=app.verbose, error_callback=app.error)
         )
