@@ -72,7 +72,7 @@ def testdoc(app: Application, robot_options_and_args: Tuple[str, ...]) -> None:
 
     try:
         profile = (
-            load_robot_config_from_path(*config_files)
+            load_robot_config_from_path(*config_files, verbose_callback=app.verbose)
             .combine_profiles(*(app.config.profiles or []), verbose_callback=app.verbose, error_callback=app.error)
             .evaluated_with_env(verbose_callback=app.verbose, error_callback=app.error)
         )
